| EuroVeg Checklist (EVC) | R Documentation |
This set of functions provides means to analyze diagnostic species of classes of the plant communities dominated by vascular plants (EVC1) as provided with Mucina et al. (2016) in Electronic Appendix S1 (EuroSpeciesList 1).
evcLookup()
evcCode(obj)
evcClass(obj, plot)
evcMatrix(obj, select, restrict, weighted = TRUE)
evc2vegsoup(obj, restrict, select)
obj |
A |
plot |
|
select |
|
restrict |
|
weighted |
A |
Given an object where species (taxa) are mapped to vegetation classes in the
taxonomy in a single column named "evc.class.code" ...
evcCode returns a list with class assignments.
evcClass expands the "evc.class.code" string and casts a
species by class matrix for a given plot.
evcMatrix returns a matrix as in evcClass for the whole object.
evcLookup() returns a look table of class codes as used in Mucina et
al. (2016).
evc2vegsoup aggregates species according to their class membership and
uses these as instaed of the original species.
Nothing here yet.
Roland Kaiser
Mucina, L. et. al (2016). Vegetation of Europe: hierarchical floristic classification system of vascular plant, bryophyte, lichen, and algal communities. Applied Vegetation Science, 19:3-264
Ellenberg ecological indicator values
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.